<?php

/*
 *  Simple shortcode which works for logged in users. It gives them link like http://site.com/?fvplayer_download=http://private-videos.site.com/video.mp4 which checks if the user is logged in and adds the signature/Secure Token and initiates the download. Also logs into Simple History plugin
 */

if( !class_exists('FV_Player_Pro_Download') ) :

class FV_Player_Pro_Download {
  
  function __construct() {
    add_action( 'admin_init', array( $this, 'register_meta_boxes' ), 20 );
    
    add_shortcode( 'fvplayer_download', array( $this, 'shortcode' ) );
    
    if( isset($_GET['fvplayer_download']) ) {
      add_action( 'init', array( $this, 'download') );
    }
  }
  
  function download() {
    if( !isset($_GET['fvplayer_download']) ) return;
    
    $message = $_GET['fvplayer_download']." from '".get_the_title($_GET['post_id'])."' (".$_GET['post_id'].") IP ".$_SERVER['REMOTE_ADDR'];
    
    if( empty($_GET['signature']) || empty($_GET['expire']) ) {
      if( function_exists("SimpleLogger") ) SimpleLogger()->warning("Unathorized video download attempt (no signature) ".$message);
      wp_die('Error processing download.');
    }
    
    $check = md5( $_GET['fvplayer_download'].$_SERVER['REMOTE_ADDR'].$_GET['expire'].NONCE_SALT.get_current_user_id());    
    
    if( get_current_user_id() == 0 ) {
      if( function_exists("SimpleLogger") ) SimpleLogger()->warning("Unathorized video download attempt (user not logged in) ".$message);
      wp_die('Error processing download.');
    }
    
    if( $check != $_GET['signature'] ) {
      if( function_exists("SimpleLogger") ) SimpleLogger()->warning("Unathorized video download attempt (bad signature) ".$message);
      wp_die('Error processing download.');
    }
    
    if( $_GET['expire'] < time() ) {
      if( function_exists("SimpleLogger") ) SimpleLogger()->warning("Expired video link ".$message);
      wp_die('Your link has expired, please go back and reload the page.');
    }    
    
    if( function_exists("SimpleLogger") ) SimpleLogger()->info("User downloaded video ".$message);
    
    global $fv_fp;
    $src = $fv_fp->get_video_src($_GET['fvplayer_download'], array( 'dynamic' => true, 'url_only' => true ) );
    wp_redirect($src);
    exit;
  }
  
  function get_link_template() {
    global $fv_fp;    
    $html = '<a download="%name%" class="fvplayer_download %class%" href="%src%">%caption%</a>';
    if( isset($fv_fp->conf['pro']['download_template']) && $fv_fp->conf['pro']['download_template'] ) $html = stripslashes($fv_fp->conf['pro']['download_template']);
    return $html;
  }
  
  function options() {
    global $fv_fp;
    ?>
    <p><?php _e('Use the <code>[fvplayer_download src="..." caption="..."]</code> shortcode to provide downloadable video to your site members - logged in users.', 'fv-player-pro'); ?></p>
    <table class="form-table2" style="margin: 5px; ">
      <tr>
        <td style="vertical-align:top"><label for="pro[download_template]"><?php _e('Link template', 'fv-player-pro'); ?>:</label></td>
        <td>
          <input type="text" size="40" name="pro[download_template]" id="pro[download_template]" value="<?php echo esc_attr($this->get_link_template()); ?>" />
          <p class="description"><?php _e('Available tags: <code>%name%</code> <code>%class%</code> <code>%src%</code> <code>%capton%</code>', 'fv-player-pro'); ?></p>
        </td>
      </tr>
      <tr>
        <td colspan="4">
          <input type="submit" name="fv-wp-flowplayer-submit" class="button-primary" value="<?php _e('Save All Changes', 'fv-player-pro'); ?>" style="margin-top: 2ex;"/>
        </td>
      </tr>         
    </table>
    <?php
  }
  
  function register_meta_boxes() {
    add_meta_box( 'fv_player_pro_download', __('Download (beta)', 'fv-player-pro'), array( $this, 'options' ), 'fv_flowplayer_settings', 'normal', 'low' );
  }
  
  function shortcode( $args ) {
    global $post;
    if( get_current_user_id() == 0 ) return;  //  todo: causing issues with aMember?
    
    global $fv_fp_scripts;
    if( !isset($fv_fp_scripts) ) $fv_fp_scripts = array();  //  todo: some better way of signaling to FV Player it should load its JS!
    
    $args = wp_parse_args( $args, array('caption' => __('Download'), 'class' => '' ) );
    
    $expire = time()+3600;
    $src = add_query_arg( 'fvplayer_download', $args['src'], get_home_url() );
    $src = add_query_arg( 'post_id', $post->ID, $src );
    $src = add_query_arg( 'expire', $expire, $src );
    $src = add_query_arg( 'signature', md5($args['src'].$_SERVER['REMOTE_ADDR'].$expire.NONCE_SALT.get_current_user_id()), $src );
    $aSrc = explode( '/', strrev( $args['src'] ), 2 );
    $name = strrev( $aSrc[0] );
    
    $html = $this->get_link_template();
    
    $html = str_replace( '%name%', esc_attr($name), $html );
    $html = str_replace( '%class%', $args['class'], $html );
    $html = str_replace( '%src%', esc_attr($src), $html );
    $html = str_replace( '%caption%', $args['caption'], $html );
    
    $html .= '<div style="display: none" class="fvplayer_download_hint">'.__('Please click again with right mouse button and select "Save As..."', 'fv-player-pro').'</div>';
    
    return $html;
  }

}
global $FV_Player_Pro_Download;
$FV_Player_Pro_Download = new FV_Player_Pro_Download;

endif;
