<?php
/*
Plugin Name: FV Player Pro
Plugin URI: http://foliovision.com/wordpress/plugins/fv-wordpress-flowplayer
Description: Provides Vimeo integration, Lightbox and more for FV Flowplayer
Version: 6.6.3.1
Author: Foliovision
Author URI: http://foliovision.com/
*/

if( !class_exists('FV_Player_Pro_loader') ) :

include( dirname(__FILE__).'/fp-api-private.php' );

class FV_Player_Pro_loader extends FV_Player_Pro_Foliopress_Plugin_Private {
  
  var $strPluginSlug = 'fv-player-pro';
  
  var $version = '6.6.3.1';
	
	function __construct() {
    add_filter( 'option_fv-player-pro-release', array( $this, 'query_arg_release_selection' ) );
    
    if( $this->get_release() == 'beta' ) {
      require_once( dirname(__FILE__).'/beta/fv-player-pro.class.php' );
      
      // read the version number from the actual plugin class
      global $FV_Player_Pro;
      $this->version = $FV_Player_Pro->version; // for FV updates
      add_filter( 'all_plugins', array( $this, 'admin__adjust_plugin_version') ); // for plugins screen     
       
    } else if( $this->get_release() == 'stable' ) {
      require_once( dirname(__FILE__).'/stable/fv-player-pro.class.php' );
    } else {
      require_once( dirname(__FILE__).'/fv-player-pro.class.php' );
    }
    
    $flowplayer_opt = get_option('fvwpflowplayer');
    $this->license_key = ( isset($flowplayer_opt['key']) && !empty($flowplayer_opt['key']) ) ? $flowplayer_opt['key'] : false;
    
    parent::__construct();
    parent::auto_updates();
    
    add_action( 'admin_init', array( $this, 'admin_init' ) );
    add_action( 'admin_footer', array( $this, 'admin_footer' ) );
    add_action( 'admin_notices', array( $this, 'admin_notice') );
    
    
    add_action( 'admin_notices', array( $this, 'admin__version_switcher_start'), 999999 );
    add_action( 'fv_player_settings_pre', array( $this, 'admin__version_switcher') );
    add_action( 'fv_flowplayer_admin_buttons_after', array( $this, 'admin__version_switcher_script') );
  }


  
  function admin_footer() {
    if( isset($_POST['fv-player-pro-release']) && isset($_REQUEST['fv_player_pro_switch']) && wp_verify_nonce( $_REQUEST['fv_player_pro_switch'], 'fv_player_pro_switch') ) {
      update_option('fv-player-pro-release',$_POST['fv-player-pro-release']);
      
      global $fv_fp;
      $fv_fp->css_writeout();
    }
  }
  
  function admin_init() {
    parent::setLicenseTransient();

    $aCheck = get_transient( $this->strPluginSlug . '_license' );
    if( !empty($aCheck->expired) ) {
      add_filter( 'site_transient_update_plugins', array( $this, 'fv_player_remove_update' ) );
      add_action( 'admin_notices', array( $this, 'admin_notice_license_error') );
      add_action( 'fv_player_settings_pre', array( $this, 'admin_notice_license_error') );
    }
    
    if( !empty($aCheck->error) ) {
      add_action( 'admin_notices', array( $this, 'admin_notice_license_error') );
      add_action( 'fv_player_settings_pre', array( $this, 'admin_notice_license_error') );
    }
  }
  
  function admin_notice() {
    if( isset($_GET['page']) && $_GET['page'] == 'fvplayer' && $this->get_release() == 'beta' ) : ?>
      <div class="updated">
        <p>
<?php _e('FV Player Pro: You are currently using the beta release, please review the changelog for any "Beta:" changes and test your videos carefully.', 'fv-player-pro'); ?>
        </p>
      </div>
    <?php endif;
  }
  
  function admin_notice_license_error() {
    $screen = get_current_screen();
    if( $screen && $screen->id == 'plugins' || did_action('fv_player_settings_pre') ) {
      $aCheck = get_transient( $this->strPluginSlug . '_license' );
      if( ( !empty($aCheck->expired) || !empty($aCheck->error) ) && ( !empty($aCheck->message) || !empty($aCheck->changelog) ) ) :
      ?>
        <div class="updated">
          <?php if( !empty($aCheck->message) ) echo $aCheck->message; ?>
          <?php if( !empty($aCheck->changelog) ) echo $aCheck->changelog; ?>
        </div>
      <?php endif;
    }
  }
  
  function admin__adjust_plugin_version( $aPlugins ) {
    global $FV_Player_Pro;
    $current_plugin = str_replace( dirname(dirname(__FILE__)).'/','', __FILE__ );
    if( !empty($aPlugins[$current_plugin]) && !empty($aPlugins[$current_plugin]['Version']) ) {
      $aPlugins[$current_plugin]['Version'] = $FV_Player_Pro->version;
    }
    return $aPlugins;
  }
  
  function admin__version_switcher() {
    $html = ob_get_clean();
    
    $select = "<select id='fv-player-pro-release' name='fv-player-pro-release'>";
    if( $this->admin__check_code('beta') ) $select .= "<option".( $this->get_release() == 'beta' ? " selected" : "" )." value='beta'>Beta</option>";
    if( $this->admin__check_code('release') ) $select .= "<option".( $this->get_release() == 'release' ? " selected" : "" )." value='release'>Release</option>";
    if( $this->admin__check_code('stable') ) $select .= "<option".( $this->get_release() == 'stable' ? " selected" : "" )." value='stable'>Stable</option>";
    $select .= "</select>";
    
    $html = str_replace('<h2>FV Player</h2>','<form action="" method="post"><h2>FV Player Pro '.$select.'</h2><input type="hidden" name="fv_player_pro_switch" value="' . wp_create_nonce( 'fv_player_pro_switch' ) . '" /></form>',$html);
    
    echo $html;
  }
  
  function admin__version_switcher_script() {
    ?>
    <script>
    jQuery('#fv-player-pro-release').change( function() {
      var question = '';
      var version = jQuery(this).val().toLowerCase(); 

      switch( version )
      {
        case "beta":
          question = '<?php _e('Are you sure you want to switch your FV Player Pro release to beta?', 'fv-player-pro'); ?>';
          break;
        case "release":
          question = '<?php _e('Are you sure you want to switch your FV Player Pro beta to release?', 'fv-player-pro'); ?>';
          break;
        case "stable":

          break;
        default:
          console.log('version_switcher_script -> unexpected version');
      }
      
      if( !confirm(question) ) 
      {
        jQuery(this).val( '<?php echo $this->get_release(); ?>' );
        return false;
      }     
  
      jQuery('#fv-player-pro-release').parents('form').submit();
    });
    </script>
    <?php    
  }
  
  function admin__version_switcher_start() {
    if( isset($_GET['page']) && $_GET['page'] == 'fvplayer' ) ob_start();
  }
  
  function admin__check_code($directory) {
    if( $directory == 'release' ) {
      $directory = '';
    } else {
      $directory .= '/';
    }
    return file_exists( dirname(__FILE__).'/'.$directory.'fv-player-pro.class.php' );
  }

  function fv_player_remove_update( $objUpdates ) {
    if( !$objUpdates || !isset($objUpdates->response) || count($objUpdates->response) == 0 ) return $objUpdates;

    foreach( $objUpdates->response AS $key => $objUpdate ) {
      if( stripos($key,'fv-wordpress-flowplayer') === 0 ) {
        unset($objUpdates->response[$key]);      
      }
    }
    
    return $objUpdates;
  }
  
  function get_release() {
    $release = isset($_POST['fv-player-pro-release']) && isset($_REQUEST['fv_player_pro_switch']) ? $_POST['fv-player-pro-release'] : get_option('fv-player-pro-release');
    if( !$release ) {
      $release = 'release';
    }
    return $release;
  }
  
  function query_arg_release_selection( $value ) {
    if( isset($_GET['fvp_release']) && $_GET['fvp_release'] == 'z093ja' ) {
      $value = 'beta';
      add_filter('fv_flowplayer_css_writeout','__return_false');
    }
    return $value;
  }

}

global $FV_Player_Pro_loader;
$FV_Player_Pro_loader = new FV_Player_Pro_loader;

endif;
